@@ -53,7 +53,6 @@ class AzureClient():
             blob_client.upload_blob(data, max_concurrency=4, overwrite=True, validate_content=True)
 
     def upload_files(self, folder_id, selected_chunks, folder_chunks, do_tar=False, do_compress=False):
-        print('DoTar {}, DoCompress {}'.format(do_tar, do_compress))
         if folder_id[0] == '/':
             folder_id = folder_id[1:len(folder_id)]
         if folder_id[-1] == '/':
@@ -100,7 +99,6 @@ class AzureClient():
             data.write(blob_client.download_blob(validate_content=True, max_concurrency=4).readall())
 
     def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
-        print('DoTar {}, DoCompress {}'.format(do_tar, do_compress))
         if dst_folder[0] == '/':
             dst_folder = dst_folder[1:len(dst_folder)]
         if do_tar:
@@ -115,7 +113,6 @@ class AzureClient():
             os.makedirs(local_folder, exist_ok=True)
 
             folder_compress = '{}/result.{}'.format(local_folder, ext)
-            print('Compressing to {}'.format(folder_compress))
             with tarfile.open(folder_compress, verb) as tar:
                 tar.add(src_folder, arcname=dst_folder, recursive=True)
             tar.close()
