@@ -31,7 +31,6 @@ class SFTPClient:
       with open(private_key_path, 'w+') as file:
         file.write(secret_key)
       os.chmod(private_key_path, 0o600)
-      print('cloud-storage-client: key file created in {}, adding private key to ssh agent'.format(private_key_path))
 
       # Add the key to the ssh agent
       ssh_agent_setup.setup()
@@ -42,20 +41,16 @@ class SFTPClient:
       else:
         p = subprocess.run(['ssh-add', private_key_path], stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                            input=str.encode(password))
-        if p.returncode == 0:
-          print('ssh key successfully added to the agent')
-        else:
+        if p.returncode != 0:
           print('ssh key could not be added to the agent, error code: {}'.format(p.returncode))
           raise IncorrectCredentialsException(code=403)
 
       if p.returncode == 0:
         output = p.stderr.decode()
-        print(f'ssh key successfully added to the agent. {output}')
         matches = re.findall('\((.*)\)', output)
         identity = private_key_path
         if len(matches) != 0 and matches[0] != '':
           identity = matches[0]
-        print(f'identity extracted: {identity}')
       else:
         print('ssh key could not be added to the agent, error code: {}'.format(p.returncode))
         raise IncorrectCredentialsException(code=403)
@@ -146,7 +141,6 @@ class SFTPClient:
       with tarfile.open(folder_compress, verb) as tar:
         tar.add(folder, recursive=True)
       tar.close()
-      print(folder_compress, '/' + folder_id + '/' + folder_id + ext)
       try:
         self.client.put(folder_compress, folder_id + '/' + folder_id + ext)
       except paramiko.SSHException as e:
@@ -174,7 +168,6 @@ class SFTPClient:
     if not self.client.isdir(remote_folder):
       self.client.mkdir(remote_folder)
 
-    print('DoTar {}, DoCompress {}'.format(do_tar, do_compress))
     if do_tar:
       if do_compress:
         ext = '.tgz'
@@ -184,7 +177,6 @@ class SFTPClient:
         verb = 'w'
 
       folder_compress = '/tmp/result{}'.format(ext)
-      print('Compressing to {}'.format(folder_compress))
       with tarfile.open(folder_compress, verb) as tar:
         tar.add(src_folder, arcname=dst_folder, recursive=True)
       tar.close()
