@@ -52,7 +52,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _delete_file(self, file_path):
         ts = time.time()
         self.client.delete_file(file_path)
-        print('Delete file elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def delete_file(self, file_path, total_retries=4, retries_count=0, seconds_wait=0.5):
         if retries_count < total_retries:
@@ -72,7 +71,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _delete_folder(self, folder_id):
         ts = time.time()
         self.client.delete_folder(folder_id)
-        print('Delete folder elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def delete_folder(self, folder_id, total_retries=4, retries_count=0, seconds_wait=0.5):
         if retries_count < total_retries:
@@ -92,7 +90,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _download_folder(self, src_folder, dst_folder):
         ts = time.time()
         self.client.download_folder(src_folder, dst_folder)
-        print('Download folder elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def download_folder(self, src_folder, dst_folder, total_retries=4, retries_count=0, seconds_wait=0.5):
         if retries_count < total_retries:
@@ -112,7 +109,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _upload_file(self, src_file, dst_file, options):
         ts = time.time()
         self.client.upload_file(src_file, dst_file, options)
-        print('Upload file elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def upload_file(self, src_file, dst_file, total_retries=4, retries_count=0, seconds_wait=0.5, options=None):
         if retries_count < total_retries:
@@ -136,7 +132,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _upload_files(self, folder_id, selected_chunks, folder_chunks, do_tar=False, do_compress=False):
         ts = time.time()
         self.client.upload_files(folder_id, selected_chunks, folder_chunks, do_tar, do_compress)
-        print('Upload files elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def upload_files(self, folder_id, selected_chunks, folder_chunks, do_tar=False, do_compress=False, total_retries=4, retries_count=0, seconds_wait=0.5):
         if retries_count < total_retries:
@@ -156,7 +151,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _download_file(self, folder_id, selected_chunk, output_folder):
         ts = time.time()
         self.client.download_file(folder_id, selected_chunk, output_folder)
-        print('Download file elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def download_file(self, folder_id, selected_chunk, output_folder, total_retries=4, retries_count=0, seconds_wait=0.5):
         if retries_count < total_retries:
@@ -176,7 +170,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
         ts = time.time()
         self.client.upload_folder(dst_folder, src_folder, do_tar, do_compress, validate)
-        print('Upload folder elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
     def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, total_retries=4, retries_count=0, seconds_wait=0.5, validate=False):
         if retries_count < total_retries:
@@ -197,7 +190,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _list_files_folder(self, folder):
         ts = time.time()
         files = self.client.list_files_folder(folder)
-        print('List files in folder elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
         return files
 
     def list_files_folder(self, folder, total_retries=4, retries_count=0, seconds_wait=0.5):
@@ -217,7 +209,6 @@ class StorageClient(storage_adapter.StorageAdapter):
     def _get_file_size(self, filename):
         ts = time.time()
         s = self.client.get_file_size(filename)
-        print('get_file_size elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
         return s
 
     def get_file_size(self, filename, total_retries=4, retries_count=0, seconds_wait=0.5):
